Wrapper function for gsignal::butter to construct a bandpass (or
low or high pass) filter at a particular frequency. Uses the Sos form for
the filter, which works better numerically particularly for very low
frequencies.
Wrapper function for gsignal::butter to construct a bandpass (or
low or high pass) filter at a particular frequency. Uses the Sos form for
the filter, which works better numerically particularly for very low
frequencies.