Skip to contents

Body width (diameter) as a function of fractional arc length for an eel (Anguilla rostrata) and a sea lamprey (Petromyzon marinus). Used for estimating the center of mass via get_midline_center_df().

Usage

fishwidth

Format

A data frame with 20 rows and 3 columns:

s

Arc length as a fraction of body length (0 = head, 1 = tail)

eelwidth

Body width of the eel as a fraction of body length

ammowidth

Body width of the lamprey as a fraction of body length