Body width (diameter) as a function of fractional arc length for an eel
(Anguilla rostrata) and a sea lamprey (Petromyzon marinus). Used for
estimating the center of mass via get_midline_center_df().
Body width (diameter) as a function of fractional arc length for an eel
(Anguilla rostrata) and a sea lamprey (Petromyzon marinus). Used for
estimating the center of mass via get_midline_center_df().